@@ -16,7 +16,7 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     ExportableAutoScalingGroupFieldType,
@@ -27,24 +27,24 @@ from .literals import (
     StatusType,
 )
 from .type_defs import (
-    DescribeRecommendationExportJobsResponseResponseTypeDef,
+    DescribeRecommendationExportJobsResponseTypeDef,
     EBSFilterTypeDef,
-    ExportAutoScalingGroupRecommendationsResponseResponseTypeDef,
-    ExportEBSVolumeRecommendationsResponseResponseTypeDef,
-    ExportEC2InstanceRecommendationsResponseResponseTypeDef,
-    ExportLambdaFunctionRecommendationsResponseResponseTypeDef,
+    ExportAutoScalingGroupRecommendationsResponseTypeDef,
+    ExportEBSVolumeRecommendationsResponseTypeDef,
+    ExportEC2InstanceRecommendationsResponseTypeDef,
+    ExportLambdaFunctionRecommendationsResponseTypeDef,
     FilterTypeDef,
-    GetAutoScalingGroupRecommendationsResponseResponseTypeDef,
-    GetEBSVolumeRecommendationsResponseResponseTypeDef,
-    GetEC2InstanceRecommendationsResponseResponseTypeDef,
-    GetEC2RecommendationProjectedMetricsResponseResponseTypeDef,
-    GetEnrollmentStatusResponseResponseTypeDef,
-    GetLambdaFunctionRecommendationsResponseResponseTypeDef,
-    GetRecommendationSummariesResponseResponseTypeDef,
+    GetAutoScalingGroupRecommendationsResponseTypeDef,
+    GetEBSVolumeRecommendationsResponseTypeDef,
+    GetEC2InstanceRecommendationsResponseTypeDef,
+    GetEC2RecommendationProjectedMetricsResponseTypeDef,
+    GetEnrollmentStatusResponseTypeDef,
+    GetLambdaFunctionRecommendationsResponseTypeDef,
+    GetRecommendationSummariesResponseTypeDef,
     JobFilterTypeDef,
     LambdaFunctionRecommendationFilterTypeDef,
     S3DestinationConfigTypeDef,
-    UpdateEnrollmentStatusResponseResponseTypeDef,
+    UpdateEnrollmentStatusResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -77,20 +77,25 @@ class Exceptions:
     ThrottlingException: Type[BotocoreClientError]
 
 
-class ComputeOptimizerClient:
+class ComputeOptimizerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ComputeOptimizerClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#can_paginate)
         """
 
@@ -101,11 +106,11 @@ class ComputeOptimizerClient:
         filters: List["JobFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> DescribeRecommendationExportJobsResponseResponseTypeDef:
+    ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
         Describes recommendation export jobs created in the last seven days.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#describe_recommendation_export_jobs)
         """
 
@@ -118,11 +123,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableAutoScalingGroupFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportAutoScalingGroupRecommendationsResponseResponseTypeDef:
+    ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Auto Scaling groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_auto_scaling_group_recommendations)
         """
 
@@ -135,11 +140,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableVolumeFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportEBSVolumeRecommendationsResponseResponseTypeDef:
+    ) -> ExportEBSVolumeRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EBS volumes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ebs_volume_recommendations)
         """
 
@@ -152,11 +157,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableInstanceFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportEC2InstanceRecommendationsResponseResponseTypeDef:
+    ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for Amazon EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_ec2_instance_recommendations)
         """
 
@@ -169,11 +174,11 @@ class ComputeOptimizerClient:
         fieldsToExport: List[ExportableLambdaFunctionFieldType] = None,
         fileFormat: Literal["Csv"] = None,
         includeMemberAccounts: bool = None
-    ) -> ExportLambdaFunctionRecommendationsResponseResponseTypeDef:
+    ) -> ExportLambdaFunctionRecommendationsResponseTypeDef:
         """
         Exports optimization recommendations for AWS Lambda functions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#export_lambda_function_recommendations)
         """
 
@@ -187,7 +192,7 @@ class ComputeOptimizerClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#generate_presigned_url)
         """
 
@@ -199,11 +204,11 @@ class ComputeOptimizerClient:
         nextToken: str = None,
         maxResults: int = None,
         filters: List["FilterTypeDef"] = None
-    ) -> GetAutoScalingGroupRecommendationsResponseResponseTypeDef:
+    ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
         Returns Auto Scaling group recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_auto_scaling_group_recommendations)
         """
 
@@ -215,11 +220,11 @@ class ComputeOptimizerClient:
         maxResults: int = None,
         filters: List["EBSFilterTypeDef"] = None,
         accountIds: List[str] = None
-    ) -> GetEBSVolumeRecommendationsResponseResponseTypeDef:
+    ) -> GetEBSVolumeRecommendationsResponseTypeDef:
         """
         Returns Amazon Elastic Block Store (Amazon EBS) volume recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ebs_volume_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ebs_volume_recommendations)
         """
 
@@ -231,11 +236,11 @@ class ComputeOptimizerClient:
         maxResults: int = None,
         filters: List["FilterTypeDef"] = None,
         accountIds: List[str] = None
-    ) -> GetEC2InstanceRecommendationsResponseResponseTypeDef:
+    ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
         Returns Amazon EC2 instance recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_instance_recommendations)
         """
 
@@ -247,21 +252,21 @@ class ComputeOptimizerClient:
         period: int,
         startTime: Union[datetime, str],
         endTime: Union[datetime, str]
-    ) -> GetEC2RecommendationProjectedMetricsResponseResponseTypeDef:
+    ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
         Returns the projected utilization metrics of Amazon EC2 instance
         recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_ec2_recommendation_projected_metrics)
         """
 
-    def get_enrollment_status(self) -> GetEnrollmentStatusResponseResponseTypeDef:
+    def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
         Returns the enrollment (opt in) status of an account to the AWS Compute
         Optimizer service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_enrollment_status)
         """
 
@@ -273,31 +278,31 @@ class ComputeOptimizerClient:
         filters: List["LambdaFunctionRecommendationFilterTypeDef"] = None,
         nextToken: str = None,
         maxResults: int = None
-    ) -> GetLambdaFunctionRecommendationsResponseResponseTypeDef:
+    ) -> GetLambdaFunctionRecommendationsResponseTypeDef:
         """
         Returns AWS Lambda function recommendations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_lambda_function_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_lambda_function_recommendations)
         """
 
     def get_recommendation_summaries(
         self, *, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
-    ) -> GetRecommendationSummariesResponseResponseTypeDef:
+    ) -> GetRecommendationSummariesResponseTypeDef:
         """
         Returns the optimization findings for an account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#get_recommendation_summaries)
         """
 
     def update_enrollment_status(
         self, *, status: StatusType, includeMemberAccounts: bool = None
-    ) -> UpdateEnrollmentStatusResponseResponseTypeDef:
+    ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
         Updates the enrollment (opt in and opt out) status of an account to the AWS
         Compute Optimizer service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.109/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_compute_optimizer/client.html#update_enrollment_status)
         """
